==> wx-sdk-0.0.8.crate: wx-sdk-0.0.8/FEATURES.md <==
## Features Gate: `mp`, `pay`, `wxa`

### Feature `mp`  公众号
- [x] get access token  获取 api 调用 access token
- [x] clear quota  清除 api 调用计数
- [x] web oauth 网页授权
- [x] custom menu  自定义菜单
  - [x] [create custom defined menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Creating_Custom-Defined_Menu.html)
  - [x] [get current menu info](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Querying_Custom_Menus.html)
  - [x] [delete custom defined menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Deleting_Custom-Defined_Menu.html)
  - [x] [add conditional menu ](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html#0)
  - [x] [delete conditional menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html#1)
  - [x] [try match menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html#2)
  - [x] [get all menu info](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Getting_Custom_Menu_Configurations.html)
- [x] parse received event  解析微信推送消息
- [x] reply msg  回复微信消息
- [x] customer service  客服服务
- [x] assert managerment  素材管理
  - [x] [add temporary material](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/New_temporary_materials.html)
  - [x] [get temporary materials](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_temporary_materials.html)
  - [x] [add permanent asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Adding_Permanent_Assets.html)
  - [x] [get permanent asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Getting_Permanent_Assets.html)
  - [x] [delete permanent asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Deleting_Permanent_Assets.html)
  - [x] [edit permanent rich media asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Editing_Permanent_Rich_Media_Assets.html)
  - [x] [get the total count of all materials](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_the_total_of_all_materials.html)
  - [x] [get materials list](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_materials_list.html)
- [ ] [comments management](https://developers.weixin.qq.com/doc/offiaccount/Comments_management/Image_Comments_Management_Interface.html)
- [x] [user management]  用户管理
  - [x] [user tag management](https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html)
    - [x] add user tag
    - [x] get user tags
    - [x] edit user tag
    - [x] delete user tag
    - [x] get user by tag
    - [x] batch tagging users
  - [x] [update user remark](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Configuring_user_notes.html)
  - [x] [get user info](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId)
  - [x] [batch get user info](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId)
  - [x] [get subscribe openid list](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Getting_a_User_List.html)
  - [x] [get blocklist](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html)
  - [x] [batch add blocklist](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html)
  - [x] [batch undo blocklist](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html)

### Feature `pay`  微信支付

### Feature `wxa`  微信小程序
- [x] Login  登录
- [x] User Information  用户信息
- [x] datacube  数据分析
- [x] Customer Service Message  客服消息
- [ ] Message Template  模板消息
- [x] Customer Service Message  客服消息
- [x] Uniform Service Message  模板消息
- [x] Updatable Message  动态消息
- [x] Plug-In Management  插件管理
- [x] Mini Programs Nearby  附近的小程序
- [x] Mini Program Code  小程序码
- [x] Url Scheme
- [x] Url Link
- [x] Content Security  内容安全
- [x] Redpacket Cover  微信红包封面
- [ ] Ad  广告
- [x] Cloudbase  云开发
- [x] Img  图像处理
- [x] Immediate Delivery  即时配送
- [x] Internet  网络
- [ ] Live Broadcast  直播
- [x] Logistics  物流助手

==> wx-sdk-0.0.9.crate: wx-sdk-0.0.9/FEATURES.md <==
## Features Gate: `mp`, `pay`, `wxa`

### Feature `mp`  公众号
- [x] get access token  获取 api 调用 access token
- [x] clear quota  清除 api 调用计数
- [x] web oauth 网页授权
- [x] custom menu  自定义菜单
  - [x] [create custom defined menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Creating_Custom-Defined_Menu.html)
  - [x] [get current menu info](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Querying_Custom_Menus.html)
  - [x] [delete custom defined menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Deleting_Custom-Defined_Menu.html)
  - [x] [add conditional menu ](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html#0)
  - [x] [delete conditional menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html#1)
  - [x] [try match menu](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Personalized_menu_interface.html#2)
  - [x] [get all menu info](https://developers.weixin.qq.com/doc/offiaccount/Custom_Menus/Getting_Custom_Menu_Configurations.html)
- [x] parse received event  解析微信推送消息
- [x] reply msg  回复微信消息
- [x] customer service  客服服务
- [x] assert managerment  素材管理
  - [x] [add temporary material](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/New_temporary_materials.html)
  - [x] [get temporary materials](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_temporary_materials.html)
  - [x] [add permanent asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Adding_Permanent_Assets.html)
  - [x] [get permanent asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Getting_Permanent_Assets.html)
  - [x] [delete permanent asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Deleting_Permanent_Assets.html)
  - [x] [edit permanent rich media asset](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Editing_Permanent_Rich_Media_Assets.html)
  - [x] [get the total count of all materials](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_the_total_of_all_materials.html)
  - [x] [get materials list](https://developers.weixin.qq.com/doc/offiaccount/Asset_Management/Get_materials_list.html)
- [ ] [comments management](https://developers.weixin.qq.com/doc/offiaccount/Comments_management/Image_Comments_Management_Interface.html)
- [x] [user management]  用户管理
  - [x] [user tag management](https://developers.weixin.qq.com/doc/offiaccount/User_Management/User_Tag_Management.html)
    - [x] add user tag
    - [x] get user tags
    - [x] edit user tag
    - [x] delete user tag
    - [x] get user by tag
    - [x] batch tagging users
  - [x] [update user remark](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Configuring_user_notes.html)
  - [x] [get user info](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId)
  - [x] [batch get user info](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Get_users_basic_information_UnionID.html#UinonId)
  - [x] [get subscribe openid list](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Getting_a_User_List.html)
  - [x] [get blocklist](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html)
  - [x] [batch add blocklist](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html)
  - [x] [batch undo blocklist](https://developers.weixin.qq.com/doc/offiaccount/User_Management/Manage_blacklist.html)

### Feature `pay`  微信支付

### Feature `wxa`  微信小程序
- [x] Login  登录
- [x] User Information  用户信息
- [x] datacube  数据分析
- [x] Customer Service Message  客服消息
- [ ] Message Template  模板消息
- [x] Customer Service Message  客服消息
- [x] Uniform Service Message  模板消息
- [x] Updatable Message  动态消息
- [x] Plug-In Management  插件管理
- [x] Mini Programs Nearby  附近的小程序
- [x] Mini Program Code  小程序码
- [x] Url Scheme
- [x] Url Link
- [x] Content Security  内容安全
- [x] Redpacket Cover  微信红包封面
- [ ] Ad  广告
- [x] Cloudbase  云开发
- [x] Img  图像处理
- [x] Immediate Delivery  即时配送
- [x] Internet  网络
- [x] Live Broadcast  直播
- [x] Logistics  物流助手
- [x] OCR
- [x] operation  运维中心
- [x] Phone Number  手机号
- [x] Risk Control  安全风控
- [x] Search 小程序搜索
- [x] Service Market 服务市场
- [x] Short Link
- [x] soter 生物认证
- [x] Subscribe Message 订阅消息
